package com.sundata.example.action;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.sundata.common.base.ActiveUserService;
import com.sundata.common.base.BaseAction;
import com.sundata.common.base.TableData;
import com.sundata.common.util.StringUtil;
import com.sundata.example.model.ExampleSysRoleModel;
import com.sundata.example.model.ExampleSysUserModel;
import com.sundata.example.service.ExampleUserManageService;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
@Tag(name="ExampleUserManageAction", description="用户管理")
@RestController
@RequestMapping(value="/example/exampleusermanage", method=RequestMethod.POST)
public class ExampleUserManageAction extends BaseAction{
	
	@Autowired
	private ExampleUserManageService exampleUserManageService; 

	@Value("${multi.org}")
	private String multiOrg;

	@Operation(summary="用户信息初始化" , description ="用户信息初始化multiOrg" )
	@ApiResponse(description="用户信息初始化")
	@RequestMapping("/init") 
	public Map<String, Object> init(HttpServletResponse response) {
		Map<String,Object> context = new HashMap<String,Object>();
		context.put("multiOrg", multiOrg);
		return context;
	}

	
	
	@Operation(summary="用户列表查询", description = "参数:loginname、cnname、orgcode 返回：用户列表TableData<ExampleSysUserModel>")
	@ApiResponse(description="用户列表")
	@RequestMapping("/getDataList") 
	public   TableData<ExampleSysUserModel> getDataList(@RequestBody ExampleSysUserModel model,HttpServletResponse response,HttpServletRequest request) throws Exception {
		
		return  exampleUserManageService.queryPageList(model);
	}
	@Operation(summary="删除用户", description = "参数：account ")
	@RequestMapping("/delete")
	public void delete(@RequestBody List<ExampleSysUserModel> beanList, HttpServletResponse response) {
		exampleUserManageService.delete(beanList);
	
	}
	
	@Operation(summary="查看用户详细信息", description = "参数：loginname 返回：用户详细信息ExampleSysUserModel")
	@ApiResponse(description="用户详细信息")
	@RequestMapping("/getDetail") 
	public ExampleSysUserModel  getDetail(@RequestBody ExampleSysUserModel model, HttpServletRequest request, HttpServletResponse response) {
		ExampleSysUserModel data = exampleUserManageService.queryDetail(model);
		// 新增时设置登录状态默认值为未登录
		if (StringUtil.isEmpty(data.getAccount())) {
			data.setLogOn("0");
			data.setOrgcode(ActiveUserService.readActiveUser(request).getOrgCode());
		}
		return data ;
		
	
	}
	@Operation(summary="用户是否已存在", description = "参数：account 返回：true代表尚未存在，否则为提示信息 ")
	@ApiResponse(description="true代表尚未存在，否则为提示信息")
	@RequestMapping("/isNotExist")
	public String isNotExist(@RequestBody ExampleSysUserModel bean, HttpServletResponse response) {
		return  exampleUserManageService.isNotExist(bean);
	}


	@Operation(summary="保存用户信息")
	@RequestMapping("/save")
	public void save(@RequestBody ExampleSysUserModel bean,HttpServletResponse response,HttpServletRequest request) {
		if("YES".equals(multiOrg)){
			exampleUserManageService.save(bean);
		}else{
			exampleUserManageService.saveOld(bean);
		}
		
	}

	/**
	 * 用户管理功能中，配置用户对应角色时，获取角色列表
	 * @param response
	 * @param request
	 * @param account
	 * @param orgcode
	 * @return 
	 */
	@Operation(summary="获取角色列表", description = "参数：account、 orgcode 返回：TableData角色列表")
	@ApiResponse(description="角色列表")
	@RequestMapping("getUserDataList")
	public TableData<ExampleSysRoleModel> getUserRoleList(HttpServletResponse response,HttpServletRequest request,
			@RequestBody ExampleSysUserModel bean){
		return genTableData( exampleUserManageService.getUserDataList(bean.getAccount(), bean.getOrgcode()));
	}


}
