package com.sundata.example.service;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.Set;


import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.sundata.admin.AdminUtil;
import com.sundata.admin.rolemanage.model.SysRoleModel;
import com.sundata.common.base.BaseService;
import com.sundata.common.base.TableData;
import com.sundata.common.exception.BusinessException;
import com.sundata.common.util.CipherUtil;
import com.sundata.common.util.DateUtil;
import com.sundata.common.util.StringUtil;
import com.sundata.common.util.SystemUtil;
import com.sundata.example.mapper.ExampleSysUserMapper;
import com.sundata.example.model.ExampleSysRoleModel;
import com.sundata.example.model.ExampleSysUserModel;


/**
 * 
 * <br>
 * <b>功能：</b>ExampleUserManageService<br>
 * <b>作者：</b>XX<br>
 * <b>日期：</b> 2023-07-27 <br>
 *  <b>版权所有：<b>版权所有(C) 2015，WWW.BJRETOP.CN/<br>
 */
@Service
public class ExampleUserManageService extends BaseService<ExampleSysUserModel> {

	@Autowired
	private ExampleSysUserMapper<ExampleSysUserModel> exampleSysUserMapper;
	public ExampleSysUserMapper<ExampleSysUserModel> getMapper() {
		return exampleSysUserMapper;
	}
	
	/**
	 * 用户详情
	 * @param model
	 * @return
	 */
	public ExampleSysUserModel queryDetail(ExampleSysUserModel model){
		List<ExampleSysUserModel> list = getMapper().queryByloginname(model);
		if(list == null || list.size() == 0 ){
			return model;
		}else if(list.size()==1){
			ExampleSysUserModel user = list.get(0);
			user.setOldorgcode(user.getOrgcode());
			return list.get(0);
		}else{
			ExampleSysUserModel user = list.get(0);
			for(int i=1;i<list.size();i++){
				user.setAccount(user.getAccount()+","+list.get(i).getAccount());
				user.setOrgcode(user.getOrgcode()+","+list.get(i).getOrgcode());
			}
			user.setOldorgcode(user.getOrgcode());
			return user;
		}
	}
	
	
	/**
	 * 页面维护用户（单机构）
	 * @param bean
	 */
	public void saveOld(ExampleSysUserModel bean){
		bean.setAccount(bean.getLoginname());
		if(bean.getOrgcode().equals(bean.getOldorgcode())){
			getMapper().updateByLoginname(bean);
		}else{
			if(!this.isInsert(bean)){
				List<ExampleSysUserModel> deteleBeanList = new ArrayList<ExampleSysUserModel>();
				deteleBeanList.add(bean);
				this.delete(deteleBeanList);
			}
			this.insertSysUser(bean,true);
		}
	}
	
	/**
	 * 页面维护用户（多机构）
	 * @param bean
	 */
	public void save(ExampleSysUserModel bean) {
		if(this.isInsert(bean)){ //新增
			String[] orgStr = bean.getOrgcode().split(",");
			
			//for(String str : orgStr){
			for(int i=0;i<orgStr.length;i++){
				bean.setOrgcode(orgStr[i]);
				bean.setAccount(bean.getLoginname()+"_"+orgStr[i]);
				if(i == 0)
					this.insertSysUser(bean,true);
				else
					this.insertSysUser(bean,false);
			}
		}else{ //修改
			if(bean.getOrgcode().equals(bean.getOldorgcode())){
				getMapper().updateByLoginname(bean);
			
			}else{
				List<ExampleSysUserModel> deteleBeanList = new ArrayList<ExampleSysUserModel>();
				List<String> orglist = new ArrayList<String>(); 
						orglist.addAll(Arrays.asList(bean.getOrgcode().split(",")));
				List<String> oldlist = Arrays.asList(bean.getOldorgcode().split(","));
				List<String> accoutlist = Arrays.asList(bean.getAccount().split(","));
				//原有的
				for(int i=0;i<oldlist.size();i++){
					String str = oldlist.get(i);
					if(orglist.contains(str)){
						bean.setAccount(accoutlist.get(i));
						bean.setOrgcode(str);
						getMapper().updateByLoginname(bean);
						
						orglist.remove(str);
					}else{
						bean.setAccount(accoutlist.get(i));
						bean.setOrgcode(str);
						deteleBeanList.add(bean);
					}
				}
				//删除原有的
				this.delete(deteleBeanList);
				//新增
				for(String str : orglist){
					bean.setOrgcode(str);
					bean.setAccount(bean.getLoginname()+"_"+str);
					this.insertSysUser(bean,true);
				}
			}
		}
	}
	/**
	 * 新增用户并校验用户是否已存在
	 * @param bean
	 * @validate true 校验唯一性
	 */
	public void insertSysUser(ExampleSysUserModel bean,boolean validate){
		String orgcode = bean.getOrgcode();
		//新增,查询所有loginname一样的用户
		if(this.isInsert(bean)){
			bean.setOrgcode("");
		}
		List<ExampleSysUserModel> list = getMapper().queryByloginname(bean);
		
		if(list != null && list.size()>0 && validate){
			if(this.isInsert(bean)){
				throw new BusinessException("用户代码["+bean.getLoginname()+"]已被占用，请修改或联系管理员修改该用户的所属机构");
			}else
				throw new BusinessException(bean.getOrgcode()+"机构,用户代码["+bean.getLoginname()+"]已被占用，请修改");
		}
		bean.setOrgcode(orgcode);
		if(StringUtil.isEmpty(bean.getCreattime())){
			bean.setCreattime(AdminUtil.queryWorkDateStr());
		}
		if(StringUtil.isEmpty(bean.getPsw())){
			bean.setPsw(CipherUtil.digest(bean.getLoginname()+AdminUtil.queryParamValue("INITPASSWORD")));
		}else{
			//暂时没有用到，用户新增时没有密码
			bean.setPsw(CipherUtil.digest(bean.getLoginname()+bean.getPsw()));
		}
		if(StringUtil.isEmpty(bean.getModifypwdate())){
			bean.setModifypwdate(DateUtil.getcurDate());
		}
		getMapper().insert(bean);
	}

	public void delete(List<ExampleSysUserModel> beanList) {		
		super.delete(beanList.toArray());
	}

	/**
	 * 分页查询
	 * @param model 带分页信息的查询条件
	 * @return 
	 * @return 查询结果Map
	 */
	public  TableData<ExampleSysUserModel> queryPageList(ExampleSysUserModel model) {
		Map<String,Object> ordersort=model.getOrdersort();
		//获取后台排序
		if(ordersort!=null&&!ordersort.isEmpty()) {
			//获取排序列
			Set<String> cols = ordersort.keySet();	
			String col=cols.iterator().next();
			model.setOrdercol(col);
			//获取排序方式
			String sort=(String) ordersort.get(col);
			if("ascend".equals(sort)) {
				model.setSoertype("asc");
			}else  if("descend".equals(sort)){
				model.setSoertype("desc");
			}
			
		}

		if(SystemUtil.isUsingOracle())
			model.setDbtype("ora");
		else if(SystemUtil.isUsingMySQL())
			model.setDbtype("mysql");
		else
			model.setDbtype("db2");
		return queryPage(false, model);
	}
	
	/**
	 * 查询该用户 可以设置的岗位 
	 * 查询当前及直接间接上级机构的角色,当前机构级别在 岗位的最低级别和最高级别 之间 
	 * @param account
	 * @param orgcode
	 * @return
	 */
	public List<ExampleSysRoleModel>  getUserDataList(String account,String orgcode){
		return getMapper().getUserDataList(account,orgcode);
	}

	

}
