package com.sundata.internalevaluation.configuration.service;

import com.sundata.common.exception.BusinessException;
import com.sundata.common.util.JsonUtil;
import com.sundata.internalevaluation.configuration.controller.DataSetConfigAction;
import com.sundata.internalevaluation.configuration.mapper.DataSetConfigMapper;
import com.sundata.internalevaluation.configuration.model.DataSetConfigModel;
import com.sundata.internalevaluation.configuration.model.DataSourcesModel;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class DataSetConfigService {
    static final Logger log = LoggerFactory.getLogger(DataSetConfigService.class);

    @Autowired
    DataSetConfigMapper dataSetConfigMapper;

    /**
     * @author: 张艳杰
     * @methodsName: getDataList
     * @description: 数据集配置初始化
     * @param: DataSetConfigModel model
     * @return: List<DataSetConfigModel>
     * @throws:
     */
    public List<DataSetConfigModel> getDataList(DataSetConfigModel model) {
        return dataSetConfigMapper.getDataList(model);
    }

    /**
     * @author: 张艳杰
     * @methodsName: createData
     * @description: 数据集配置新增
     * @param: IndexConfigModel model
     * @return:
     * @throws:
     */
    public void createData(DataSetConfigModel model) {
        if (null != model && null != model.getDataSourcesNos() && model.getDataSourcesNos().size()>0) {
            for (String sourceNo : model.getDataSourcesNos()) {
                model.setDataSourcesNo(sourceNo);
                dataSetConfigMapper.createAssociation(model);
            }
        }
        dataSetConfigMapper.createData(model);
    }

    /**
     * @author: 张艳杰
     * @methodsName: createData
     * @description: 数据集配置删除
     * @param: IndexConfigModel model
     * @return:
     * @throws:
     */
    public void deleteRows(DataSetConfigModel model) {
        dataSetConfigMapper.deleteAssociation(model.getDataSetNo());
        dataSetConfigMapper.deleteRows(model);
    }

    /**
     * @author: 张艳杰
     * @methodsName: createData
     * @description: 数据集配置修改
     * @param: IndexConfigModel model
     * @return:
     * @throws:
     */
    public void updateExistData(DataSetConfigModel model) {
        dataSetConfigMapper.deleteAssociation(model.getDataSetNo());
        if (null != model && null != model.getDataSourcesNos() && model.getDataSourcesNos().size()>0) {
            for (String sourceNo : model.getDataSourcesNos()) {
                model.setDataSourcesNo(sourceNo);
                dataSetConfigMapper.createAssociation(model);
            }
        }
        dataSetConfigMapper.updateExistData(model);
    }

    /**
     * @author: 张艳杰
     * @methodsName: selectDetailData
     * @description: 数据来源配置查询
     * @param:  DataSetConfigModel model
     * @return:
     * @throws:
     */
    public DataSetConfigModel selectDetailData(DataSetConfigModel model) {
        DataSetConfigModel configModel = dataSetConfigMapper.selectDetailData(model);
        List<String> dataSourcesNos = new ArrayList<>();
        List<DataSetConfigModel> selectModel = dataSetConfigMapper.selectAssociation(configModel);
        if (null != selectModel && selectModel.size()>0) {
            for (DataSetConfigModel m : selectModel) {
                dataSourcesNos.add(m.getDataSourcesNo());
            }
        }
        configModel.setDataSourcesNos(dataSourcesNos);
        return configModel;
    }
}
