package com.sundata.internalevaluation.configuration.service;

import com.sundata.common.util.JsonUtil;
import com.sundata.internalevaluation.configuration.mapper.RiskControlStrategyMapper;
import com.sundata.internalevaluation.configuration.model.RiskControlStrategyModel;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class RiskControlStrategyService {

    @Autowired
    RiskControlStrategyMapper riskControlStrategyMapper;

    /**
     * @author: 张艳杰
     * @methodsName: getDataList
     * @description: 风控策略配置初始化
     * @param: RiskControlStrategyModel model
     * @return: List<RiskControlStrategyModel>
     * @throws:
     */
    public List<RiskControlStrategyModel> getDataList(RiskControlStrategyModel model) {
        return riskControlStrategyMapper.getDataList(model);
    }

    /**
     * @author: 张艳杰
     * @methodsName: createData
     * @description: 风控策略配置新增
     * @param: RiskControlStrategyModel model
     * @return:
     * @throws:
     */
    public void createData(RiskControlStrategyModel model) {
        // 插入对应的风控规则和指标清单关联
        if (null != model && null != model.getIndexListNos() && !model.getIndexListNos().isEmpty()) {
            for (String index : model.getIndexListNos()) {
                model.setIndexListNo(index);
                riskControlStrategyMapper.createIndexListAssociation(model);
            }
        }
        // 插入对应的风控规则和指标清单关联
        if (null != model && null != model.getRulesNos() && !model.getRulesNos().isEmpty()) {
            for (String rules : model.getRulesNos()) {
                model.setRulesNo(rules);
                riskControlStrategyMapper.createRulesAssociation(model);
            }
        }
        // 规则表插入数据
        riskControlStrategyMapper.createData(model);
    }

    /**
     * @author: 张艳杰
     * @methodsName: deleteRows
     * @description: 风控策略配置删除
     * @param: RiskControlStrategyModel model
     * @return:
     * @throws:
     */
    public void deleteRows(RiskControlStrategyModel model) {
        riskControlStrategyMapper.deleteIndexListAssociation(model);
        riskControlStrategyMapper.deleteRulesAssociation(model);
        riskControlStrategyMapper.deleteRows(model.getRiskControlStrategyNo());
    }

    /**
     * @author: 张艳杰
     * @methodsName: updateExistData
     * @description: 风控策略配置修改
     * @param: RiskControlStrategyModel model
     * @return:
     * @throws:
     */
    public void updateExistData(RiskControlStrategyModel model) {
        riskControlStrategyMapper.updateExistData(model);
        // 插入对应的风控规则和指标清单关联
        if (null != model && null != model.getIndexListNos() && !model.getIndexListNos().isEmpty()) {
            riskControlStrategyMapper.deleteIndexListAssociation(model);
            for (String index : model.getIndexListNos()) {
                model.setIndexListNo(index);
                riskControlStrategyMapper.createIndexListAssociation(model);
            }

        }
        // 插入对应的风控规则和指标清单关联
        if (null != model && null != model.getRulesNos() && !model.getRulesNos().isEmpty()) {
            riskControlStrategyMapper.deleteRulesAssociation(model);
            for (String rules : model.getRulesNos()) {
                model.setRulesNo(rules);
                riskControlStrategyMapper.createRulesAssociation(model);
            }
        }
    }

    /**
     * @author: 张艳杰
     * @methodsName: selectDetailData
     * @description: 风控策略配置查询
     * @param: RiskControlStrategyModel model
     * @return:
     * @throws:
     */
    public RiskControlStrategyModel selectDetailData(RiskControlStrategyModel model) {
        List<String> rulesList = new ArrayList<>();
        List<String> indexList = new ArrayList<>();
        RiskControlStrategyModel selectModel = riskControlStrategyMapper.selectDetailData(model);
        List<RiskControlStrategyModel> associationList = riskControlStrategyMapper.selectIndexListAssociation(selectModel.getRiskControlStrategyNo());
        List<RiskControlStrategyModel> rulesAssociationList = riskControlStrategyMapper.selectRulesAssociationData(selectModel.getRiskControlStrategyNo());
        associationList.addAll(rulesAssociationList);
        if (null != associationList && !associationList.isEmpty()) {
            for (RiskControlStrategyModel m : associationList) {
                if (null!= m.getRulesNo() && !m.getRulesNo().isEmpty()) {
                    rulesList.add(m.getRulesNo());
                }
                if (null!= m.getIndexListNo() && !m.getIndexListNo().isEmpty()) {
                    indexList.add(m.getIndexListNo());
                }
            }
            selectModel.setIndexListNos(indexList);
            selectModel.setRulesNos(rulesList);
        }
        return selectModel;
    }
}
