package com.sundata.internalevaluation.configuration.service;

import com.sundata.internalevaluation.configuration.model.SysInterfaceParam;
import com.sundata.internalevaluation.configuration.mapper.SysInterfaceParamMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.UUID;

@Service
public class SysInterfaceParamService {

    @Autowired
    private SysInterfaceParamMapper SysInterfaceParamMapper;


    /**
     * 查询所有记录
     *
     * @return 返回集合，没有返回空List
     */
    public List<SysInterfaceParam> listAll() {
        return SysInterfaceParamMapper.listAll();
    }


    /**
     * 根据主键查询
     *
     * @param id 主键
     * @return 返回记录，没有返回null
     */
    public SysInterfaceParam getById(String id) {
        return SysInterfaceParamMapper.getById(id);
    }


    /**
     * 根据接口id查询参数列表
     *
     * @param interfaceId 主键
     * @return 返回记录，没有返回null
     */
    public List<SysInterfaceParam> getByInterfaceId(String interfaceId) {
        return SysInterfaceParamMapper.getByInterfaceId(interfaceId);
    }

    /**
     * 根据接口id删除参数信息
     *
     * @param interfaceId 主键
     * @return 返回记录，没有返回null
     */
    public int deleteByInterfaceId(String interfaceId) {
        return SysInterfaceParamMapper.deleteByInterfaceId(interfaceId);
    }

    /**
     * 批量插入
     *
     * @param paramList 新增的记录
     * @return 返回影响行数
     */
    public int insertBatch(List<SysInterfaceParam> paramList, String interfaceId) {
        if (paramList == null || paramList.isEmpty()) {
            return 1;
        }
        paramList.forEach(param -> {
            // IdUtils.getSnowflakeId().toString()
            param.setId(UUID.randomUUID().toString());
            param.setInterfaceId(interfaceId);
        });
        return SysInterfaceParamMapper.insertBatch(paramList);
    }


    /**
     * 新增，插入所有字段
     *
     * @param SysInterfaceParam 新增的记录
     * @return 返回影响行数
     */
    public int insert(SysInterfaceParam SysInterfaceParam) {
        return SysInterfaceParamMapper.insert(SysInterfaceParam);
    }

    /**
     * 新增，忽略null字段
     *
     * @param SysInterfaceParam 新增的记录
     * @return 返回影响行数
     */
    public int insertIgnoreNull(SysInterfaceParam SysInterfaceParam) {
        return SysInterfaceParamMapper.insertIgnoreNull(SysInterfaceParam);
    }

    /**
     * 修改，修改所有字段
     *
     * @param SysInterfaceParam 修改的记录
     * @return 返回影响行数
     */
    public int update(SysInterfaceParam SysInterfaceParam) {
        return SysInterfaceParamMapper.update(SysInterfaceParam);
    }

    /**
     * 修改，忽略null字段
     *
     * @param SysInterfaceParam 修改的记录
     * @return 返回影响行数
     */
    public int updateIgnoreNull(SysInterfaceParam SysInterfaceParam) {
        return SysInterfaceParamMapper.updateIgnoreNull(SysInterfaceParam);
    }

    /**
     * 删除记录
     *
     * @param SysInterfaceParam 待删除的记录
     * @return 返回影响行数
     */
    public int delete(SysInterfaceParam SysInterfaceParam) {
        return SysInterfaceParamMapper.delete(SysInterfaceParam);
    }

}